@@ -4,8 +4,6 @@
 
 ## Possible optimizations for compressed lists:
 ## - order/sort: unlist, order by split factor first
-## - sum/mean: unlist, rowsum() with split factor
-##   - or probably faster would be a rangeSums function
 ## - cumsum: unlist, cumsum and subtract offsets
 
 .ATOMIC_TYPES <- c("logical", "integer", "numeric", "complex",
@@ -455,6 +453,24 @@ setMethod("Math2", "SimpleAtomicList",
 setMethod("Summary", "AtomicList",
           function(x, ..., na.rm = FALSE) {
             sapply(x, .Generic, na.rm = na.rm)
+        })
+
+setMethod("any", "CompressedAtomicList", function(x, na.rm = FALSE) {
+              stopifnot(isTRUEorFALSE(na.rm))
+              ans <- sum(x, na.rm=TRUE) > 0L
+              if (!na.rm) {
+                  ans[!ans & any(is.na(x), na.rm=TRUE)] <- NA
+              }
+              ans
+          })
+
+setMethod("all", "CompressedAtomicList", function(x, na.rm = FALSE) {
+              stopifnot(isTRUEorFALSE(na.rm))
+              ans <- !any(!x, na.rm=TRUE)
+              if (!na.rm) {
+                  ans[ans & any(is.na(x), na.rm=TRUE)] <- NA
+              }
+              ans
           })
 
 rowsumCompressedList <- function(x, ..., na.rm = FALSE) {
@@ -468,9 +484,30 @@ rowsumCompressedList <- function(x, ..., na.rm = FALSE) {
   setNames(ans, names(x))
 }
 
-setMethod("sum", "CompressedNumericList", rowsumCompressedList)
-setMethod("sum", "CompressedIntegerList", rowsumCompressedList)
-setMethod("sum", "CompressedLogicalList", rowsumCompressedList)
+setCompressedListSummaryMethod <- function(fun, where=topenv(parent.frame()))
+{
+    types <- c("Logical", "Integer", "Numeric")
+    classNames <- paste0("Compressed", types, "List")
+    lapply(classNames, function(className) {
+               setMethod(fun, className, function(x, na.rm = FALSE) {
+                             stopifnot(isTRUEorFALSE(na.rm))
+                             .Call(paste0(className, "_", fun), x, na.rm)
+                         }, where=where)
+           })
+}
+
+setCompressedListSummaryMethod("sum")
+setCompressedListSummaryMethod("min")
+setCompressedListSummaryMethod("max")
+
+setMethods("range",
+           list("CompressedLogicalList",
+                "CompressedIntegerList",
+                "CompressedNumericList"),
+           function(x, na.rm=FALSE) {
+               stopifnot(isTRUEorFALSE(na.rm))
+               cbind(min(x, na.rm=na.rm), max(x, na.rm=na.rm))
+           })
 
 setMethod("Summary", "CompressedRleList",
           function(x, ..., na.rm = FALSE) {
@@ -757,6 +794,20 @@ setMethod("mean", "AtomicList",
     function(x, ...) sapply(x, mean, ...)
 )
 
+setMethods("mean",
+           list("CompressedLogicalList",
+                "CompressedIntegerList",
+                "CompressedNumericList"),
+           function(x, trim = 0, na.rm = FALSE) {
+               stopifnot(isTRUEorFALSE(na.rm))
+               stopifnot(isSingleNumber(trim))
+               if (trim > 0) {
+                   return(callNextMethod())
+               }
+               lens <- if (na.rm) sum(!is.na(x)) else elementLengths(x)
+               sum(x, na.rm=na.rm) / lens
+           })
+
 setMethod("var", c("AtomicList", "missing"),
     function(x, y=NULL, na.rm=FALSE, use)
     {
@@ -912,6 +963,20 @@ setMethod("unstrsplit", "CharacterList",
     function(x, sep="") unstrsplit(as.list(x), sep=sep)
 )
 
+setMethod("paste", "CompressedAtomicList",
+          function(..., sep=" ", collapse=NULL) {
+              args <- lapply(list(...), as, "CharacterList")
+              lens <- do.call(pmax, lapply(args, elementLengths))
+              args <- lapply(args, recycleListElements, lens)
+              unlisted <- lapply(args, unlist, use.names=FALSE)
+              ans <- relist(do.call(paste, c(unlisted, sep=sep)),
+                            PartitioningByWidth(lens))
+              if (!is.null(collapse)) {
+                  ans <- unstrsplit(ans, collapse)
+              }
+              ans
+          })
+
 ### - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 ### Rle methods
 ###
@@ -1044,20 +1109,27 @@ setMethod("unlist", "SimpleFactorList",
 .showAtomicList <- function(object, minLines, ...)
 {
     len <- length(object)
+    object_names <- names(object)
     k <- min(minLines, len)
-    d <- len - minLines 
+    d <- len - minLines
     for (i in seq_len(k)) {
-        nm <- names(object)[i]
-        if (length(nm) > 0 && nchar(nm) > 0)
-            label <- paste("[[\"", nm, "\"]]", sep = "")
-        else
-            label <- paste("[[", i, "]]", sep = "")
+        if (is.null(object_names)) {
+            label <- i
+        } else {
+            nm <- object_names[[i]]
+            if (is.na(nm)) {
+                label <- "NA"
+            } else {
+                label <- paste0("\"", nm, "\"")
+            }
+        }
+        label <- paste0("[[", label, "]]")
         if (length(object[[i]]) == 0) {
             cat(label, " ", sep = "")
             print(object[[i]])
         } else {
-            cat(BiocGenerics:::labeledLine(label, object[[i]], labelSep = "",
-                                           count = FALSE))
+            cat(S4Vectors:::labeledLine(label, object[[i]], labelSep = "",
+                                        count = FALSE))
         }
     }
     if (d > 0)
