@@ -33,10 +33,10 @@ setAs("IntervalTree", "IRanges", function(from) {
 
 setAs("IRanges", "IntervalTree", function(from) {
   msg <- c("IntervalTree objects and the \"intervaltree\" algorithm used ",
-           "in findOverlaps() and family are deprecated. Please use the ",
+           "in findOverlaps() and family are defunct. Please use the ",
            "\"nclist\" algorithm instead. See the 'algorithm' argument ",
            "in ?findOverlaps for more information.")
-  .Deprecated(msg=wmsg(msg))
+  .Defunct(msg=wmsg(msg))
 
   validObject(from)
   ptr <- .Call2("IntegerIntervalTree_new", from, PACKAGE="IRanges")
