@@ -33,8 +33,6 @@ setMethod("length", "MaskCollection", function(x) length(nir_list(x)))
 
 setMethod("width", "MaskCollection", function(x) x@width)
 
-setGeneric("active", function(x) standardGeneric("active"))
-
 setMethod("active", "MaskCollection",
     function(x)
     {
@@ -44,10 +42,6 @@ setMethod("active", "MaskCollection",
     }
 )
 
-setGeneric("active<-", signature="x",
-    function(x, value) standardGeneric("active<-")
-)
-
 setReplaceMethod("active", "MaskCollection",
     function(x, value)
     {
@@ -66,11 +60,10 @@ setReplaceMethod("names", "MaskCollection",
     function(x, value)
     {
         if (is.null(value)) {
-            x@NAMES <- as.character(NA)
+            x@NAMES <- NA_character_
             return(x)
-        } else {
-            value <- as.character(value)
         }
+        value <- as.character(value)
         ii <- is.na(value)
         if (any(ii))
             value[ii] <- ""
