@@ -80,18 +80,18 @@ setMethod("width", "RangedData",
             width(unlist(ranges(x), use.names=FALSE))
           })
 setReplaceMethod("start", "RangedData",
-                 function(x, check=TRUE, value) {
-                   start(ranges(x), check=check) <- value
+                 function(x, ..., value) {
+                   start(ranges(x), ...) <- value
                    x
                  })
 setReplaceMethod("end", "RangedData",
-                 function(x, check=TRUE, value) {
-                   end(ranges(x), check=check) <- value
+                 function(x, ..., value) {
+                   end(ranges(x), ...) <- value
                    x
                  })
 setReplaceMethod("width", "RangedData",
-                 function(x, check=TRUE, value) {
-                   width(ranges(x), check=check) <- value
+                 function(x, ..., value) {
+                   width(ranges(x), ...) <- value
                    x
                  })
 setMethod("length", "RangedData", function(x) length(ranges(x)))
@@ -114,7 +114,6 @@ setReplaceMethod("universe", "RangedData",
                    x
                  })
 
-setGeneric("score", function(x, ...) standardGeneric("score"))
 setMethod("score", "RangedData",
           function(x) {
               score <- x[["score"]]
@@ -123,7 +122,6 @@ setMethod("score", "RangedData",
               score
           })
 
-setGeneric("score<-", function(x, ..., value) standardGeneric("score<-"))
 setReplaceMethod("score", "RangedData",
                  function(x, value) {
                      if (!is.numeric(value))
@@ -215,7 +213,7 @@ setReplaceMethod("columnMetadata", "RangedData", function(x, value) {
   nms <- names(x)
   if (length(nms) != length(x))
     "length(names(x)) must equal length(x)"
-  else if (!is.character(nms) || anyMissing(nms) || anyDuplicated(nms))
+  else if (!is.character(nms) || S4Vectors:::anyMissing(nms) || anyDuplicated(nms))
     "names(x) must be a character vector without any NA's or duplicates"
   else NULL
 }
@@ -287,8 +285,14 @@ RangedData <- function(ranges = IRanges(), ..., space = NULL, universe = NULL)
   }
   universe(ranges) <- universe
 
-  if (hasDots) 
-    values <- DataFrame(...) ## at least one column specified
+  if (hasDots) {
+    args <- list(...)
+    if (length(args) == 1L && is(args[[1L]], "SplitDataFrameList")) {
+      values <- unlist(args[[1L]], use.names=FALSE)
+    } else {
+      values <- DataFrame(...)
+    }
+  }
   else
     values <- new2("DataFrame", nrows = N, check=FALSE)
   if (N != nrow(values)) {
@@ -296,7 +300,7 @@ RangedData <- function(ranges = IRanges(), ..., space = NULL, universe = NULL)
       stop("length of value(s) in '...' greater than length of 'ranges'")
     if (nrow(values) == 0 || N %% nrow(values) != 0)
       stop("length of 'ranges' not a multiple of length of value(s) in '...'")
-    rind <- recycleVector(seq_len(nrow(values)), N)
+    rind <- S4Vectors:::recycleVector(seq_len(nrow(values)), N)
     values <- values[rind,,drop=FALSE]
   }
   rownames(values) <- NAMES ## ensure these are identical
@@ -401,20 +405,20 @@ setMethod("[", "RangedData",
               if (is.numeric(i)) {
                 if (!is.integer(i))
                   i <- as.integer(i)
-                if (anyMissingOrOutside(i, upper = lx))
+                if (S4Vectors:::anyMissingOrOutside(i, upper = lx))
                   return("subscript contains NAs or out of bounds indices")
-                if (anyMissingOrOutside(i, 0L, lx) &&
-                    anyMissingOrOutside(i, upper = 0L))
+                if (S4Vectors:::anyMissingOrOutside(i, 0L, lx) &&
+                    S4Vectors:::anyMissingOrOutside(i, upper = 0L))
                   return("negative and positive indices cannot be mixed")
               } else if (is.logical(i)) {
-                if (anyMissing(i))
+                if (S4Vectors:::anyMissing(i))
                   return("subscript contains NAs")
                 if (length(i) > lx)
                   return("subscript out of bounds")
               } else if ((is.character(i) || is.factor(i))) {
-                if (anyMissing(i))
+                if (S4Vectors:::anyMissing(i))
                   return("subscript contains NAs")
-                if (anyMissing(match(i, nms)))
+                if (S4Vectors:::anyMissing(match(i, nms)))
                   return("mismatching names")
               } else if (!is.null(i)) {
                 return("invalid subscript type")
@@ -469,7 +473,7 @@ setMethod("[", "RangedData",
                     dummy <- seq_len(nrow(x))
                     names(dummy) <- rownames(x)
                     i <- dummy[i]
-                    if (anyMissing(i)) ## cannot subset by NAs yet
+                    if (S4Vectors:::anyMissing(i)) ## cannot subset by NAs yet
                       stop("invalid rownames specified")
                   }
                   starts <- cumsum(c(1L, head(elementLengths(x), -1)))
@@ -481,8 +485,8 @@ setMethod("[", "RangedData",
                 }
                 isplit <- split(i, igroup)
                 names(isplit) <- names(x)
-                ranges <- subset_List_by_List(ranges, isplit)
-                values <- subset_List_by_List(values, isplit)
+                ranges <- S4Vectors:::subset_List_by_List(ranges, isplit)
+                values <- S4Vectors:::subset_List_by_List(values, isplit)
                 if (drop) {
                   ok <- (elementLengths(ranges) > 0)
                   ranges <- ranges[ok]
@@ -503,16 +507,6 @@ setMethod("[", "RangedData",
             x
           })
 
-### Dummy "extractROWS" method.
-setMethod("extractROWS", "RangedData",
-    function(x, i)
-    {
-        if (is(i, "Ranges"))
-            i <- as.integer(i)
-        x[i, , drop=FALSE]
-    }
-)
-
 ### - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 ### Combining and splitting.
 ###
@@ -576,6 +570,49 @@ setMethod("rbind", "RangedData", function(..., deparse.level=1) {
 ### Coercion
 ###
 
+### The 2 functions, as.data.frame.RangesList() and
+### as.data.frame.DataFrameList() are needed for as.data.frame.RangedData().
+###
+### A new as.data.frame,List method was implemented in BioC 2.15 and
+### is now used by all List classes. Because the RangedData class is being 
+### phased out, we want to retain the old behavior. In order to do that 
+### we have to keep these 2 helpers because as.data.frame.RangedData() 
+### uses old methods from both RangesList and DataFrameList.
+###
+### These helpers are not exported.
+.as.data.frame.RangesList <- function(x, row.names=NULL, optional=FALSE, ...)
+{
+    if (!(is.null(row.names) || is.character(row.names)))
+        stop("'row.names'  must be NULL or a character vector")
+    x <- as(x, "CompressedIRangesList")
+    spaceLevels <- seq_len(length(x))
+    if (length(names(x)) > 0) {
+        spaceLabels <- names(x)
+    } else {
+        spaceLabels <- as.character(spaceLevels)
+    }
+    data.frame(space =
+               factor(rep.int(seq_len(length(x)), elementLengths(x)),
+                      levels = spaceLevels,
+                      labels = spaceLabels),
+               as.data.frame(unlist(x, use.names = FALSE)),
+               row.names = row.names,
+               stringsAsFactors = FALSE)
+}
+
+.as.data.frame.DataFrameList <- function(x, row.names=NULL, 
+                                         optional=FALSE, ...)
+{
+    if (!(is.null(row.names) || is.character(row.names)))
+        stop("'row.names' must be NULL or a character vector")
+    if (!missing(optional) || length(list(...)))
+        warning("'optional' and arguments in '...' ignored")
+    stacked <- stack(x)
+    if (is.null(row.names))
+        row.names <- rownames(stacked)
+    as.data.frame(stacked, row.names = row.names, optional = optional)
+}
+
 ### S3/S4 combo for as.data.frame.RangedData
 as.data.frame.RangedData <- function(x, row.names=NULL, optional=FALSE, ...)
 {
@@ -583,8 +620,8 @@ as.data.frame.RangedData <- function(x, row.names=NULL, optional=FALSE, ...)
         stop("'row.names'  must be NULL or a character vector")
     if (!missing(optional) || length(list(...)))
         warning("'optional' and arguments in '...' ignored")
-    data.frame(as.data.frame(ranges(x)),
-               as.data.frame(values(x))[-1L],
+    data.frame(.as.data.frame.RangesList(ranges(x)),
+               .as.data.frame.DataFrameList(values(x))[-1L],
                row.names = row.names,
                stringsAsFactors = FALSE)
 }
@@ -593,7 +630,8 @@ setMethod("as.data.frame", "RangedData",as.data.frame.RangedData)
 setAs("RangedData", "DataFrame",
       function(from)
       {
-        DataFrame(as.data.frame(ranges(from)), values(from))
+        DataFrame(as.data.frame(ranges(from)),
+                  unlist(values(from), use.names=FALSE))
       })
 
 setAs("Rle", "RangedData",
@@ -634,10 +672,11 @@ setAs("RleViewsList", "RangedData", function(from) {
                           keep.all.ranges = TRUE)
 ### FIXME: do we want to insert NAs for out of bounds views?
   score <- subject[from_ranges]
-  score_part <- seqapply(width(from_ranges), PartitioningByWidth)
+  score_part <- as(lapply(width(from_ranges), PartitioningByWidth), "RangesList")
   score_ranges <- ranges(score)
   ol <- findOverlaps(score_ranges, score_part)
-  offset <- (start(from_ranges) - start(score_part))[seqapply(ol, subjectHits)]
+  offind <- as(lapply(ol, subjectHits), "IntegerList")
+  offset <- (start(from_ranges) - start(score_part))[offind]
   ranges <- shift(ranges(ol, score_ranges, score_part), offset)
   viewNames <- lapply(from_ranges, function(x) {
     if (is.null(names(x)))
@@ -826,7 +865,7 @@ RangedDataList <- function(...)
   listData <- list(...)
   if (length(listData) == 1 && is.list(listData[[1L]]))
     listData <- listData[[1L]]
-  newList("RangedDataList", listData)
+  S4Vectors:::new_SimpleList_from_list("RangedDataList", listData)
 }
 
 setMethod("unlist", "RangedDataList",
