@@ -20,9 +20,6 @@ setMethod("length", "Ranges", function(x) length(start(x)))
 ### which is very inefficient on Ranges objects!
 setMethod("elementLengths", "Ranges", function(x) setNames(width(x), names(x)))
 
-### The "start" and "end" generics are defined in the stats package.
-setGeneric("width", function(x) standardGeneric("width"))
-
 ### The 3 default methods below provide a formalization of the relationship
 ### between the starts/widths/ends of a Ranges object. Of course Ranges
 ### subclasses need to implement at least 2 of them!
@@ -34,18 +31,6 @@ setMethod("end", "Ranges", function(x, ...) {width(x) - 1L + start(x)})
 setGeneric("mid", function(x, ...) standardGeneric("mid"))
 setMethod("mid", "Ranges", function(x) start(x) + as.integer((width(x)-1) / 2))
 
-setGeneric("start<-", signature="x",
-    function(x, check=TRUE, value) standardGeneric("start<-")
-)
-
-setGeneric("width<-", signature="x",
-    function(x, check=TRUE, value) standardGeneric("width<-")
-)
-
-setGeneric("end<-", signature="x",
-    function(x, check=TRUE, value) standardGeneric("end<-")
-)
-
 setMethod("update", "Ranges",
     function(object, ...)
         as(update(as(object, "IRanges"), ...), class(object))
@@ -107,7 +92,7 @@ as.data.frame.Ranges <- function(x, row.names=NULL, optional=FALSE, ...)
 setMethod("as.data.frame", "Ranges", as.data.frame.Ranges)
 
 setMethod("as.integer", "Ranges",
-    function(x, ...) fancy_mseq(width(x), offset=start(x)-1L)
+    function(x, ...) S4Vectors:::fancy_mseq(width(x), offset=start(x)-1L)
 )
 
 
@@ -207,7 +192,10 @@ setMethod("showAsCell", "Ranges",
 
 
 ### - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-### Testing a Ranges object.
+### isEmpty(), isNormal(), isDisjoint()
+###
+### All of them test a Ranges object as a whole and return a single TRUE or
+### FALSE.
 ###
 
 ### A Ranges object is considered empty iff all its ranges are empty.
@@ -239,6 +227,23 @@ setMethod("whichFirstNotNormal", "Ranges",
     }
 )
 
+setGeneric("isDisjoint", function(x, ...) standardGeneric("isDisjoint"))
+
+setMethod("isDisjoint", "Ranges",
+    function(x)
+    {
+        x_len <- length(x)
+        if (x_len < 2L)
+            return(TRUE)
+        x_start <- start(x)
+        x_end <- end(x)
+        oo <- order(x)
+        start2 <- x_start[oo]
+        end2 <- x_end[oo]
+        all(start2[-1L] > end2[-x_len])
+    }
+)
+
 
 ### - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 ### Core endomorphisms.
