@@ -636,6 +636,10 @@ setAs("list", "RangesList", function(from) {
   S4Vectors:::coerceToSimpleList(from, "Ranges")
 })
 
+setAs("Ranges", "RangesList", function(from) {
+          relist(from, PartitioningByEnd(seq_along(from), names=names(from)))
+      })
+
 ### - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 ### The "max" and "min" methods for NormalIRangesList objects.
 ###
@@ -679,13 +683,3 @@ setMethod("summary", "CompressedIRangesList",
           function(object)
           .Call2("CompressedIRangesList_summary", object, PACKAGE="IRanges"))
 
-
-### - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-### Splitting.
-###
-
-### Seems broken to me. We probably don't need this anyway!
-#setMethod("split", "Ranges",
-#          function(x, f, drop = FALSE, ...)
-#          do.call(RangesList, callNextMethod()))
-
