@@ -49,25 +49,25 @@ setMethod("width", "Views", function(x) width(ranges(x)))
 setMethod("names", "Views", function(x) names(ranges(x)))
 
 setReplaceMethod("start", "Views",
-    function(x, check=TRUE, value)
+    function(x, ..., value)
     {
-        x@ranges <- `start<-`(ranges(x), check=check, value)
+        start(x@ranges, ...) <- value
         x
     }
 )
 
 setReplaceMethod("end", "Views",
-    function(x, check=TRUE, value)
+    function(x, ..., value)
     {
-        x@ranges <- `end<-`(ranges(x), check=check, value)
+        end(x@ranges, ...) <- value
         x
     }
 )
 
 setReplaceMethod("width", "Views",
-    function(x, check=TRUE, value)
+    function(x, ..., value)
     {
-        x@ranges <- `width<-`(ranges(x), check=check, value)
+        width(x@ranges, ...) <- value
         x
     }
 )
@@ -75,7 +75,7 @@ setReplaceMethod("width", "Views",
 setReplaceMethod("names", "Views",
     function(x, value)
     {
-        x@ranges <- `names<-`(ranges(x), value)
+        names(x@ranges) <- value
         x
     }
 )
@@ -83,8 +83,7 @@ setReplaceMethod("names", "Views",
 setMethod("extractROWS", "Views",
     function(x, i)
     {
-        if (missing(i) || !is(i, "Ranges"))
-            i <- normalizeSingleBracketSubscript(i, x)
+        i <- normalizeSingleBracketSubscript(i, x, as.NSBS=TRUE)
         x@ranges <- extractROWS(ranges(x), i)
         mcols(x) <- extractROWS(mcols(x), i)
         x
@@ -177,10 +176,10 @@ setMethod("as.matrix", "Views", function(x, rev = FALSE, max.width = NA) {
   if (is.na(max.width)) {
     max.width <- max(width(x_ranges))
   }
-  rev <- recycleVector(rev, length(x))
+  rev <- S4Vectors:::recycleVector(rev, length(x))
   part <- PartitioningByWidth(x_ranges)
-  ord <- mseq(ifelse(rev, end(part), start(part)),
-              ifelse(rev, start(part), end(part)))
+  ord <- S4Vectors:::mseq(ifelse(rev, end(part), start(part)),
+                          ifelse(rev, start(part), end(part)))
   v <- extractROWS(subject(x), x_ranges)[ord]
   v_fill <- rep.int(NA, max.width * length(x))
   part <- PartitioningByWidth(rep(max.width, length(x)))
@@ -241,7 +240,7 @@ setMethod("c", "Views",
         if (ignore.mcols) {
             mcols(x) <- NULL
         } else  {
-            mcols(x) <- do.call(rbind.mcols, args)
+            mcols(x) <- do.call(S4Vectors:::rbind_mcols, args)
         }
         validObject(x)
         x
@@ -323,8 +322,9 @@ setMethod("viewApply", "Views",
                       ...),
               simplify = simplify)
         if (!simplify) {
-            ans <- newList("SimpleList", ans, metadata = metadata(X),
-                           mcols = mcols(X))
+            ans <- S4Vectors:::new_SimpleList_from_list("SimpleList", ans,
+                                                        metadata = metadata(X),
+                                                        mcols = mcols(X))
         }
         ans
     }
