@@ -31,6 +31,8 @@
         stop("'x' must be an IRanges object")
 
     ## 'shift' will be checked at the C level.
+    if (is(shift, "Rle"))
+        shift <- S4Vectors:::decodeRle(shift)
 
     ## Check 'width'.
     if (is.null(width)) {
@@ -42,6 +44,8 @@
     }
 
     ## 'weight' will be checked at the C level.
+    if (is(weight, "Rle"))
+        weight <- S4Vectors:::decodeRle(weight)
 
     ## Check 'circle.length'.
     if (!isSingleNumberOrNA(circle.length))
@@ -64,6 +68,25 @@
     .fold_and_truncate_coverage(ans, circle.length, width)
 }
 
+### Returns an ordinary list.
+.normarg_shift_or_weight <- function(arg, arg.label)
+{
+    if (!is.list(arg)) {
+        if (!(is.numeric(arg) ||
+              (is(arg, "Rle") && is.numeric(runValue(arg))) ||
+              is(arg, "List")))
+            stop("'", arg.label, "' must be a numeric vector ",
+                 "or a list-like object")
+        arg <- as.list(arg)
+    }
+    if (length(arg) != 0L) {
+        idx <- which(sapply(arg, is, "Rle"))
+        if (length(idx) != 0L)
+            arg[idx] <- lapply(arg[idx], S4Vectors:::decodeRle)
+    }
+    arg
+}
+
 .check_arg_names <- function(arg, arg.label, x_names, x_names.label)
 {
     arg_names <- names(arg)
@@ -110,11 +133,7 @@
     x_names <- names(x)
 
     ## Check and normalize 'shift'.
-    if (!is.list(shift)) {
-        if (!(is.numeric(shift) || is(shift, "List")))
-            stop("'shift' must be a numeric vector or list-like object")
-        shift <- as.list(shift)
-    }
+    shift <- .normarg_shift_or_weight(shift, "shift")
     .check_arg_names(shift, "shift", x_names, x_names.label)
 
     ## Check and normalize 'width'.
@@ -136,11 +155,7 @@
     }
 
     ## Check and normalize 'weight'.
-    if (!is.list(weight)) {
-        if (!(is.numeric(weight) || is(weight, "List")))
-            stop("'weight' must be a numeric vector or list-like object")
-        weight <- as.list(weight)
-    }
+    weight <- .normarg_shift_or_weight(weight, "weight")
     .check_arg_names(weight, "weight", x_names, x_names.label)
 
     ## Check and normalize 'circle.length'.
@@ -159,10 +174,10 @@
 
     ## Ready to go...
     ans_listData <- .Call2("CompressedIRangesList_coverage", x,
-                              shift, width,
-                              weight, circle.length,
-                              method,
-                              PACKAGE="IRanges")
+                           shift, width,
+                           weight, circle.length,
+                           method,
+                           PACKAGE="IRanges")
 
     ## "Fold" the coverage vectors in 'ans_listData' associated with a
     ## circular sequence.
@@ -185,10 +200,9 @@
     }
 
     names(ans_listData) <- names(x)
-    newList("SimpleRleList",
-            ans_listData,
-            metadata=metadata(x),
-            mcols=mcols(x))
+    S4Vectors:::new_SimpleList_from_list("SimpleRleList", ans_listData,
+                                         metadata=metadata(x),
+                                         mcols=mcols(x))
 }
 
 
