@@ -5,7 +5,7 @@
 ### What should go in this file?
 ###
 ### - relistToClass() generic and default method.
-### - All "relist" and "split" methods defined in IRanges should be here.
+### - All "relist" methods defined in IRanges should go here.
 ### - extractList() generic and default method.
 ###
 ### TODO: Maybe put the default methods for the reverse transformations here
@@ -94,7 +94,7 @@ setMethod("relist", c("Vector", "list"),
 
 
 ### - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-### splitAsList() and split()
+### splitAsList()
 ###
 
 ### 'f' is assumed to be an integer vector with no NAs.
@@ -203,10 +203,9 @@ setMethod("relist", c("Vector", "list"),
     relist(x, f)
 }
 
-setGeneric("splitAsList",
-           function(x, f, drop=FALSE, ...) standardGeneric("splitAsList"),
-           signature = c("x", "f"))
-
+setGeneric("splitAsList", signature=c("x", "f"),
+    function(x, f, drop=FALSE, ...) standardGeneric("splitAsList")
+)
 
 ### Took this out of the still-in-incubation LazyList package
 factorsToTableIndices <- function(factors) {
@@ -286,22 +285,6 @@ setMethod("splitAsList", c("ANY", "Rle"),
 setMethod("splitAsList", c("ANY", "List"),
           function(x, f, drop=FALSE) splitAsList_default(x, f, drop=drop))
 
-setMethod("split", c("Vector", "ANY"),
-    function(x, f, drop=FALSE) splitAsList(x, f, drop=drop)
-)
-
-setMethod("split", c("ANY", "Vector"),
-    function(x, f, drop=FALSE) splitAsList(x, f, drop=drop)
-)
-
-setMethod("split", c("Vector", "Vector"),
-    function(x, f, drop=FALSE) splitAsList(x, f, drop=drop)
-)
-
-setMethod("split", c("list", "Vector"),
-    function(x, f, drop=FALSE, ...) split(x, as.vector(f), drop=drop, ...)
-)
-
 
 ### - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 ### extractList()
@@ -337,3 +320,50 @@ setMethod("extractList", c("ANY", "ANY"),
         relist(extractROWS(x, unlisted_i), i)
     }
 )
+
+
+### - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
+### regroupBySupergroup()
+###
+### A very efficient way to concatenate groups of successive list elements
+### in 'x'.
+### 'x' must be a list-like object (typically a CompressedList object).
+### 'supergroups' must be an object that defines a partitioning of
+### 'seq_along(x)' (i.e. it could be used to do
+### 'relist(seq_along(x), supergroups)'). It will be immediately replaced with
+### 'PartitioningByEnd(supergroups)' so it should be an object that is
+### accepted by the PartitioningByEnd() constructor (note that this constructor
+### is a no-op if 'supergroups' is already a PartitioningByEnd object).
+### Return a list-like object of the same elementType() as 'x' and parallel
+### to 'supergroups'. The names on 'supergroups' are propagated but not the
+### metadata columns.
+###
+### Some properties:
+### - Behaves as an endomorphism on a CompressedList or PartitioningByEnd
+###   object.
+### - This
+###       regroupBySupergroup(x, length(x))[[1L]]
+###   is equivalent to
+###       unlist(x, use.names=FALSE)
+###
+### Other possible names for regroupBySupergroup: regroup,
+### mergeGroupsInSupergroups, combineGroupsOfListElements,
+### unlistGroupsOfListElements, unlistBySupergroup.
+###
+### TODO: Maybe export and document this?
+
+regroupBySupergroup <- function(x, supergroups)
+{
+    supergroups <- PartitioningByEnd(supergroups)
+    x_breakpoints <- end(PartitioningByEnd(x))
+    ans_breakpoints <- x_breakpoints[end(supergroups)]
+    nleading0s <- length(supergroups) - length(ans_breakpoints)
+    if (nleading0s != 0L)
+        ans_breakpoints <- c(rep.int(0L, nleading0s), ans_breakpoints)
+    ans_partitioning <- PartitioningByEnd(ans_breakpoints,
+                                          names=names(supergroups))
+    if (is(x, "PartitioningByEnd"))
+        return(ans_partitioning)
+    relist(unlist(x, use.names=FALSE), ans_partitioning)
+}
+
