@@ -41,7 +41,7 @@ setMethod("range", "RangesList",
     x_start <- start(x)
     x_end <- end(x)
     ## TEMPORARY HACK!
-    if (!require(XVector, quietly=TRUE))
+    if (!requireNamespace("XVector", quietly=TRUE))
         stop("the XVector package is required by the \"range\" method ",
              "for CompressedIRangesList objects")
     ## 'sv' and 'ev' are XIntegerViews objects (see XVector package).
