@@ -4,6 +4,36 @@
 ###
 
 
+normargAtomicList1 <- function(arg, List, lx, argname = deparse(substitute(arg)))
+{
+    if (is.vector(arg))
+        arg <- List(as.list(S4Vectors:::recycleVector(arg, lx)))
+    else if (!is(arg, "AtomicList"))
+        stop("'", argname,"' must be a vector or AtomicList object")
+    arg
+}
+
+normargAtomicList2 <- function(arg, List, lx, eln, argname = deparse(substitute(arg)))
+{
+    if (!(is.vector(arg) && length(arg) == 1L)) {
+        if (is.vector(arg))
+          arg <- as(rep(S4Vectors:::recycleVector(arg, lx), eln),
+                    class(unlist(List())))
+        else {
+          if (!is(arg, "AtomicList"))
+            stop("'arg' must be a vector or AtomicList object")
+          if (!isTRUE(all.equal(elementLengths(arg), eln,
+                                check.attributes=FALSE)))
+            arg <- mapply(S4Vectors:::recycleVector, arg, List(as.list(eln)))
+          arg <- unlist(arg, use.names=FALSE)
+        }
+    } else if (is.list(arg)){
+        arg <- unlist(arg, use.names=FALSE)
+    }
+    arg
+}
+
+
 ### - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 ### shift()
 ###
@@ -25,7 +55,7 @@ setMethod("shift", "Ranges",
         } else {
             x <- update(x, start=new_start, width=width(x), check=FALSE)
         }
-        if (!normargUseNames(use.names))
+        if (!S4Vectors:::normargUseNames(use.names))
             names(x) <- NULL
         validObject(x)
         x
@@ -84,7 +114,7 @@ setMethod("narrow", "Ranges",
         ans_start <- start(x) + start(solved_SEW) - 1L
         ans_width <- width(solved_SEW)
         x <- update(x, start=ans_start, width=ans_width, check=FALSE)
-        if (!normargUseNames(use.names))
+        if (!S4Vectors:::normargUseNames(use.names))
             names(x) <- NULL
         x
     }
@@ -145,7 +175,7 @@ setMethod("narrow", "IntervalForest",
 #        for (i in seq_len(length(x))) {
 #            x@cnirl[[i]] <- restrict(x[[i]], start=start2[i], end=end2[i])
 #        }
-#        if (!normargUseNames(use.names))
+#        if (!S4Vectors:::normargUseNames(use.names))
 #            names(x) <- NULL
 #        x
 #    }
@@ -163,13 +193,101 @@ setMethod("narrow", "MaskCollection",
                                 1L - solved_start)
         )
         x@width <- solved_width
-        if (!normargUseNames(use.names))
+        if (!S4Vectors:::normargUseNames(use.names))
             names(x) <- NULL
         x
     }
 )
 
 
+### - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
+### resize()
+###
+
+setGeneric("resize", signature="x",
+    function(x, width, fix="start", use.names=TRUE, ...)
+        standardGeneric("resize")
+)
+
+setMethod("resize", "Ranges",
+    function(x, width, fix="start", use.names=TRUE)
+    {
+        if (is(x, "NormalIRanges"))
+            stop("resizing a NormalIRanges object is not supported")
+        lx <- length(x)
+        if (!is.numeric(width) || S4Vectors:::anyMissing(width))
+            stop("'width' must be a numeric vector without NA's")
+        if (!is.integer(width))
+            width <- as.integer(width)
+        if (S4Vectors:::anyMissingOrOutside(width, 0L))
+            stop("'width' values must be non-negative")
+        if (!(is.character(fix) ||
+              (is(fix, "Rle") && is.character(runValue(fix)))) || 
+            (length(fix) == 0L && length(x) > 0L) ||
+            (length(setdiff(unique(fix),
+                            c("start", "end", "center"))) > 0)) {
+            stop("'fix' must be a character vector or character Rle ",
+                 "with values in \"start\", \"end\", and \"center\"")
+        }
+        if (!is(fix, "Rle"))
+            fix <- Rle(fix)
+        if (length(fix) != lx)
+            fix <- rep(fix, length.out = lx)
+        ans_width <- S4Vectors:::recycleVector(width, lx)
+        ans_start <- start(x)
+        if (!identical(runValue(fix), "start")) {
+            fixEnd <- as(fix == "end", "IRanges")
+            if (length(fixEnd) > 0) {
+                value <- extractROWS(ans_start, fixEnd) +
+                         (extractROWS(width(x), fixEnd) -
+                          extractROWS(ans_width, fixEnd))
+                ans_start <- replaceROWS(ans_start, fixEnd, value)
+            }
+            fixCenter <- as(fix == "center", "IRanges")
+            if (length(fixCenter) > 0) {
+                value <- extractROWS(ans_start, fixCenter) +
+                         (extractROWS(width(x), fixCenter) -
+                          extractROWS(ans_width, fixCenter)) %/% 2L
+                ans_start <- replaceROWS(ans_start, fixCenter, value)
+            }
+        }
+        x <- update(x, start=ans_start, width=ans_width, check=FALSE)
+        if (!S4Vectors:::normargUseNames(use.names))
+            names(x) <- NULL
+        x
+    }
+)
+
+setMethod("resize", "RangesList",
+          function(x, width, fix = "start", use.names = TRUE)
+          {
+              lx <- length(x)
+              width <- normargAtomicList1(width, IntegerList, lx)
+              fix <- normargAtomicList1(fix, CharacterList, lx)
+              mendoapply(resize, x = x, width = width, fix = fix,
+                         MoreArgs = list(use.names = use.names))
+          })
+
+setMethod("resize", "CompressedIRangesList",
+          function(x, width, fix = "start", use.names = TRUE)
+          {
+              lx <- length(x)
+              eln <- elementLengths(x)
+              width <- normargAtomicList2(width, IntegerList, lx, eln)
+              fix <- normargAtomicList2(fix, CharacterList, lx, eln)
+              slot(x, "unlistData", check=FALSE) <-
+                resize(x@unlistData, width = width, fix = fix,
+                       use.names = use.names)
+              x
+          })
+
+setMethod("resize", "IntervalForest",
+          function(x, width, fix = "start", use.names = TRUE)
+            as(resize(as(x, "CompressedIRangesList"),
+                      width = width, fix = fix, use.names = use.names),
+               "IntervalForest"))
+
+
 ### - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 ### flank()
 ###
@@ -185,23 +303,32 @@ setMethod("flank", "Ranges",
         if (is(x, "NormalIRanges"))
             stop("flanking a NormalIRanges object is not supported")
         width <- recycleIntegerArg(width, "width", length(x))
-        if (!is.logical(start) || anyMissing(start))
+        if (!is.logical(start) || S4Vectors:::anyMissing(start))
             stop("'start' must be logical without NA's")
-        start <- recycleVector(unname(start), length(x))
+        start <- S4Vectors:::recycleVector(unname(start), length(x))
         if (!isTRUEorFALSE(both))
             stop("'both' must be TRUE or FALSE")
+        ans_start <- integer(length(x))
         if (both) {
-            ans_start <-
-              ifelse(start, start(x) - abs(width), end(x) - abs(width) + 1L)
-            ans_width <- 2L * abs(width)
+            idx1 <- which(start)
+            idx2 <- which(!start)
+            width <- abs(width)
+            ans_width <- 2L * width
+            ans_start[idx1] <- start(x)[idx1] - width[idx1]
+            ans_start[idx2] <- end(x)[idx2] - width[idx2] + 1L
         } else {
-            ans_start <-
-              ifelse(start, ifelse(width < 0L, start(x), start(x) - width),
-                     ifelse(width < 0L, end(x) + width + 1L, end(x) + 1L))
+            idx1a <- which(start & width >= 0L)
+            idx1b <- which(start & width < 0L)
+            idx2a <- which(!start & width >= 0L)
+            idx2b <- which(!start & width < 0L)
             ans_width <- abs(width)
+            ans_start[idx1a] <- start(x)[idx1a] - width[idx1a]
+            ans_start[idx1b] <- start(x)[idx1b]
+            ans_start[idx2a] <- end(x)[idx2a] + 1L
+            ans_start[idx2b] <- end(x)[idx2b] + width[idx2b] + 1L
         }
         x <- update(x, start=ans_start, width=ans_width, check=FALSE)
-        if (!normargUseNames(use.names))
+        if (!S4Vectors:::normargUseNames(use.names))
             names(x) <- NULL
         x
     }
@@ -322,101 +449,13 @@ setMethod("reflect", "Ranges",
             bounds <- head(bounds, length(x))
         ans_start <- (2L * start(bounds) + width(bounds) - 1L) - end(x)
         x <- update(x, start=ans_start, width=width(x), check=FALSE)
-        if (!normargUseNames(use.names))
+        if (!S4Vectors:::normargUseNames(use.names))
             names(x) <- NULL
         x
     }
 )
 
 
-### - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-### resize()
-###
-
-setGeneric("resize", signature="x",
-    function(x, width, fix="start", use.names=TRUE, ...)
-        standardGeneric("resize")
-)
-
-setMethod("resize", "Ranges",
-    function(x, width, fix="start", use.names=TRUE)
-    {
-        if (is(x, "NormalIRanges"))
-            stop("resizing a NormalIRanges object is not supported")
-        lx <- length(x)
-        if (!is.numeric(width) || anyMissing(width))
-            stop("'width' must be a numeric vector without NA's")
-        if (!is.integer(width))
-            width <- as.integer(width)
-        if (anyMissingOrOutside(width, 0L))
-            stop("'width' values must be non-negative")
-        if (!(is.character(fix) ||
-              (is(fix, "Rle") && is.character(runValue(fix)))) || 
-            (length(fix) == 0L && length(x) > 0L) ||
-            (length(setdiff(unique(fix),
-                            c("start", "end", "center"))) > 0)) {
-            stop("'fix' must be a character vector or character Rle ",
-                 "with values in \"start\", \"end\", and \"center\"")
-        }
-        if (!is(fix, "Rle"))
-            fix <- Rle(fix)
-        if (length(fix) != lx)
-            fix <- rep(fix, length.out = lx)
-        ans_width <- recycleVector(width, lx)
-        ans_start <- start(x)
-        if (!identical(runValue(fix), "start")) {
-            fixEnd <- as(fix == "end", "IRanges")
-            if (length(fixEnd) > 0) {
-                value <- extractROWS(ans_start, fixEnd) +
-                         (extractROWS(width(x), fixEnd) -
-                          extractROWS(ans_width, fixEnd))
-                ans_start <- replaceROWS(ans_start, fixEnd, value)
-            }
-            fixCenter <- as(fix == "center", "IRanges")
-            if (length(fixCenter) > 0) {
-                value <- extractROWS(ans_start, fixCenter) +
-                         (extractROWS(width(x), fixCenter) -
-                          extractROWS(ans_width, fixCenter)) %/% 2L
-                ans_start <- replaceROWS(ans_start, fixCenter, value)
-            }
-        }
-        x <- update(x, start=ans_start, width=ans_width, check=FALSE)
-        if (!normargUseNames(use.names))
-            names(x) <- NULL
-        x
-    }
-)
-
-setMethod("resize", "RangesList",
-          function(x, width, fix = "start", use.names = TRUE)
-          {
-              lx <- length(x)
-              width <- normargAtomicList1(width, IntegerList, lx)
-              fix <- normargAtomicList1(fix, CharacterList, lx)
-              mendoapply(resize, x = x, width = width, fix = fix,
-                         MoreArgs = list(use.names = use.names))
-          })
-
-setMethod("resize", "CompressedIRangesList",
-          function(x, width, fix = "start", use.names = TRUE)
-          {
-              lx <- length(x)
-              eln <- elementLengths(x)
-              width <- normargAtomicList2(width, IntegerList, lx, eln)
-              fix <- normargAtomicList2(fix, CharacterList, lx, eln)
-              slot(x, "unlistData", check=FALSE) <-
-                resize(x@unlistData, width = width, fix = fix,
-                       use.names = use.names)
-              x
-          })
-
-setMethod("resize", "IntervalForest",
-          function(x, width, fix = "start", use.names = TRUE)
-            as(resize(as(x, "CompressedIRangesList"),
-                      width = width, fix = fix, use.names = use.names),
-               "IntervalForest"))
-
-
 ### - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 ### restrict()
 ###
@@ -449,11 +488,11 @@ setGeneric("restrict", signature="x",
 ### Note that the only mode compatible with a NormalIRanges object is 0L.
 Ranges.restrict <- function(x, start, end, drop.ranges.mode, use.names)
 {
-    if (!isNumericOrNAs(start))
+    if (!S4Vectors:::isNumericOrNAs(start))
         stop("'start' must be a vector of integers")
     if (!is.integer(start))
         start <- as.integer(start)
-    if (!isNumericOrNAs(end))
+    if (!S4Vectors:::isNumericOrNAs(end))
         stop("'end' must be a vector of integers")
     if (!is.integer(end))
         end <- as.integer(end)
@@ -463,9 +502,9 @@ Ranges.restrict <- function(x, start, end, drop.ranges.mode, use.names)
         if (length(end) == 0L || length(end) > length(x))
             stop("invalid 'end' length")
     }
-    start <- recycleVector(start, length(x))
-    end <- recycleVector(end, length(x))
-    use.names <- normargUseNames(use.names)
+    start <- S4Vectors:::recycleVector(start, length(x))
+    end <- S4Vectors:::recycleVector(end, length(x))
+    use.names <- S4Vectors:::normargUseNames(use.names)
 
     ans_start <- start(x)
     ans_end <- end(x)
@@ -524,7 +563,7 @@ setMethod("restrict", "Ranges",
     {
         if (!isTRUEorFALSE(keep.all.ranges))
             stop("'keep.all.ranges' must be TRUE or FALSE")
-        use.names <- normargUseNames(use.names)
+        use.names <- S4Vectors:::normargUseNames(use.names)
         if (is(x, "NormalIRanges")) {
             if (keep.all.ranges)
                 stop("'keep.all.ranges=TRUE' is not supported ",
@@ -624,7 +663,7 @@ setMethod("threebands", "IRanges",
 setMethod("Ops", c("Ranges", "numeric"),
     function(e1, e2)
     {
-        if (anyMissing(e2))
+        if (S4Vectors:::anyMissing(e2))
             stop("NA not allowed as zoom factor")
         if ((length(e1) < length(e2) && length(e1)) ||
             (length(e1) && !length(e2)) ||
