@@ -19,8 +19,8 @@ setMethod("precede", c("Ranges", "RangesORmissing"),
       select <- match.arg(select)
       s <- start(subject)
       ord <- NULL
-      if (isNotSorted(s)) {
-        ord <- orderInteger(s)
+      if (S4Vectors:::isNotSorted(s)) {
+        ord <- S4Vectors:::orderInteger(s)
         s <- s[ord]
       }
       if (select == "all") {
@@ -30,7 +30,7 @@ setMethod("precede", c("Ranges", "RangesORmissing"),
       i <- findInterval(end(x), s) + 1L
       i[i > length(s)] <- NA
       if (select == "all") {
-        .vectorToHits(i, srle, ord)
+        vectorToHits(i, srle, ord)
       } else {
         if (!is.null(ord))
           i <- ord[i]
@@ -47,8 +47,8 @@ setMethod("follow", c("Ranges", "RangesORmissing"),
       select <- match.arg(select)
       e <- end(subject)
       ord <- NULL
-      if (isNotSorted(e)) {
-        ord <- orderInteger(e)
+      if (S4Vectors:::isNotSorted(e)) {
+        ord <- S4Vectors:::orderInteger(e)
         e <- e[ord]
       }
       if (select == "all") {
@@ -58,7 +58,7 @@ setMethod("follow", c("Ranges", "RangesORmissing"),
       i <- findInterval(start(x) - 1L, e)
       i[i == 0] <- NA        
       if (select == "all") {
-        .vectorToHits(i, srle, ord)
+        vectorToHits(i, srle, ord)
       } else {
         if (!is.null(ord))
           i <- ord[i]
@@ -72,16 +72,9 @@ setMethod("follow", c("Ranges", "RangesORmissing"),
 ### nearest()
 ###
 
-.hitsMatrixToVector <- function(hitsMatrix, queryLength) {
-  hitsMatrix <-
-    hitsMatrix[diffWithInitialZero(hitsMatrix[,1L,drop=TRUE]) != 0L,,
-                drop=FALSE]
-  ans <- rep.int(NA_integer_, queryLength)
-  ans[hitsMatrix[,1L,drop=TRUE]] <- hitsMatrix[,2L,drop=TRUE]
-  ans
-}
-
-.vectorToHits <- function(i, srle, ord) {
+### Used in GenomicRanges.
+### TODO: Move to Hits-class.R
+vectorToHits <- function(i, srle, ord) {
   lx <- length(i)
   v <- !is.na(i)
   i <- i[v]
@@ -90,28 +83,28 @@ setMethod("follow", c("Ranges", "RangesORmissing"),
   m <- cbind(queryHits = rep(seq(lx)[v], w),
              subjectHits = if (!is.null(ord)) ord[subj] else subj)
   if (!is.null(ord))
-    m <- m[orderIntegerPairs(m[,1L], m[,2L]),,drop=FALSE]
-  ## unname() required because in case 'm' has only 1 row
-  ## 'm[ , 1L]' and 'm[ , 2L]' will return a named atomic vector
-  new("Hits", queryHits = unname(m[ , 1L]), subjectHits = unname(m[ , 2L]),
-              queryLength = lx, subjectLength = length(srle))
+    m <- m[S4Vectors:::orderIntegerPairs(m[,1L], m[,2L]),,drop=FALSE]
+  Hits(m[ , 1L], m[ , 2L], lx, length(srle))
 }
 
 setGeneric("nearest", function(x, subject, ...) standardGeneric("nearest"))
 
 setMethod("nearest", c("Ranges", "RangesORmissing"),
-          function(x, subject, select = c("arbitrary", "all"))
+          function(x, subject, select = c("arbitrary", "all"),
+                   algorithm = c("nclist", "intervaltree"))
           {
             select <- match.arg(select)
             if (!missing(subject)) {
-              ol <- findOverlaps(x, subject, select = select)
+              ol <- findOverlaps(x, subject, select = select,
+                                 algorithm = match.arg(algorithm))
             } else {
               subject <- x
-              ol <- findOverlaps(x, select = select, ignoreSelf = TRUE)
+              ol <- findOverlaps(x, select = select,
+                                 algorithm = match.arg(algorithm),
+                                 ignoreSelf = TRUE)
             }
             if (select == "all") {
-              m <- as.matrix(ol)
-              olv <- .hitsMatrixToVector(m, length(x))
+              olv <- selectHits(ol, select="first")
             } else olv <- ol
             x <- x[is.na(olv)]
             before <- precede(x, subject,
@@ -119,32 +112,27 @@ setMethod("nearest", c("Ranges", "RangesORmissing"),
             after <- follow(x, subject,
                             if (select == "all") "all" else "last")
             if (select == "all") {
-              before_m <- as.matrix(before)
-              before <- .hitsMatrixToVector(before_m, length(x))
-              after_m <- as.matrix(after)
-              after <- .hitsMatrixToVector(after_m, length(x))
+              before0 <- before
+              before <- selectHits(before, select="first")
+              after0 <- after
+              after <- selectHits(after, select="first")
             }
             leftdist <- (start(subject)[before] - end(x))
             rightdist <- (start(x) - end(subject)[after])
             left <- leftdist < rightdist
             left[is.na(left)] <- is.na(after)[is.na(left)]
             if (select == "all") {
-              filterMatchMatrix <- function(m, i) {
-                qrle <- Rle(m[,1L])
-                qstart <- qend <- integer(length(i))
-                qstart[runValue(qrle)] <- start(qrle)
-                qend[runValue(qrle)] <- end(qrle)
-                rows <- as.integer(IRanges(qstart[i], qend[i]))
-                m <- m[rows,,drop=FALSE]
+              filterHits <- function(hits, i) {
+                m <- as.matrix(hits[as(hits, "IRanges")[i]])
                 m[,1L] <- map[m[,1L]]
                 m
               }
               map <- which(is.na(olv))
               right <- !left
               left[leftdist == rightdist] <- TRUE
-              m <- rbind(m, filterMatchMatrix(before_m, left),
-                         filterMatchMatrix(after_m, right))
-              m <- m[orderIntegerPairs(m[,1L], m[,2L]),, drop=FALSE]
+              m <- rbind(as.matrix(ol), filterHits(before0, left),
+                                        filterHits(after0, right))
+              m <- m[S4Vectors:::orderIntegerPairs(m[,1L], m[,2L]),, drop=FALSE]
               ## unname() required because in case 'm' has only 1 row
               ## 'm[ , 1L]' and 'm[ , 2L]' will return a named atomic vector
               ol@queryHits <- unname(m[ , 1L])
@@ -181,26 +169,34 @@ setGeneric("distanceToNearest",
            function(x, subject = x, ...) standardGeneric("distanceToNearest"))
 
 setMethod("distanceToNearest", c("Ranges", "RangesORmissing"),
-          function(x, subject, select = c("arbitrary", "all"))
-          {
-            select <- match.arg(select)
-            if (missing(subject)) {
-              subject <- x
-              x_nearest <- nearest(x, select = select)
-            } else {
-              x_nearest <- nearest(x, subject, select = select)
-            }
-            if (select == "arbitrary") {
-              x_nearest <- cbind(queryHits = seq_len(length(x)),
-                                 subjectHits = x_nearest)
-            } else {
-              x_nearest <- as.matrix(x_nearest)
-            }
-            distance = distance(x[x_nearest[,1]], subject[x_nearest[,2]])
-            new("Hits", queryHits=x_nearest[,1],
-                        subjectHits=x_nearest[,2],
-                        queryLength=length(x), 
-                        subjectLength=length(subject),
-                        elementMetadata=DataFrame(distance=distance))
-          })
+    function(x, subject, select = c("arbitrary", "all"),
+             algorithm = c("nclist", "intervaltree"))
+    {
+        select <- match.arg(select)
+        if (missing(subject)) {
+            subject <- x
+            x_nearest <- nearest(x, select = select,
+                                 algorithm = match.arg(algorithm))
+        } else {
+            x_nearest <- nearest(x, subject, select = select,
+                                 algorithm = match.arg(algorithm))
+        }
+        if (select == "arbitrary") {
+            queryHits <- seq_along(x)[!is.na(x_nearest)]
+            subjectHits <- x_nearest[!is.na(x_nearest)]
+        } else {
+            queryHits <- queryHits(x_nearest)
+            subjectHits <- subjectHits(x_nearest)
+        }
+
+        if (!length(subjectHits) || all(is.na(subjectHits))) {
+            Hits(queryLength=length(x), 
+                 subjectLength=length(subject),
+                 distance=integer(0))
+        } else {
+            distance = distance(x[queryHits], subject[subjectHits])
+            Hits(queryHits, subjectHits, length(x), length(subject), distance)
+        }
+    }
+)
 
