@@ -28,7 +28,7 @@
 ### union()
 ###
 
-setMethod("union", c("IRanges", "IRanges"),
+setMethod("union", c("Ranges", "Ranges"),
     function(x, y, ...)
     {
         ## We need to downgrade 'x' to an IRanges instance 'x0' so 'c(x0, y)'
@@ -53,9 +53,9 @@ setMethod("union", c("CompressedIRangesList", "CompressedIRangesList"),
           function(x, y) {
             len <- max(length(x), length(y))
             if (length(x) != len)
-              x <- x[recycleVector(seq_len(length(x)), len)]
+              x <- x[S4Vectors:::recycleVector(seq_len(length(x)), len)]
             if (length(y) != len)
-              y <- y[recycleVector(seq_len(length(y)), len)]
+              y <- y[S4Vectors:::recycleVector(seq_len(length(y)), len)]
             xy <- c(unlist(x, use.names = FALSE), unlist(y, use.names = FALSE))
             xy_list <- split(xy, factor(c(togroup(x), togroup(y)),
                                         seq_len(length(x))))
@@ -63,29 +63,12 @@ setMethod("union", c("CompressedIRangesList", "CompressedIRangesList"),
             reduce(xy_list, drop.empty.ranges=TRUE)
           })
 
-setMethod("union", c("Hits", "Hits"),
-    function(x, y)
-    {
-        m <- match(y, x)
-        y <- y[is.na(m)]
-        q_hits <- c(queryHits(x), queryHits(y))
-        s_hits <- c(subjectHits(x), subjectHits(y))
-        oo <- orderIntegerPairs(q_hits, s_hits)
-        q_hits <- q_hits[oo]
-        s_hits <- s_hits[oo]
-        new2("Hits",
-             queryHits=q_hits, subjectHits=s_hits,
-             queryLength=queryLength(x), subjectLength=subjectLength(x),
-             check=FALSE)
-    }
-)
-
 
 ### - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 ### intersect()
 ###
 
-setMethod("intersect", c("IRanges", "IRanges"),
+setMethod("intersect", c("Ranges", "Ranges"),
     function(x, y, ...)
     {
         if (length(x) == 0L)
@@ -110,18 +93,12 @@ setMethod("intersect", c("CompressedIRangesList", "CompressedIRangesList"),
             setdiff(x, gaps(y, start = startx, end = endx))
           })
 
-setMethod("intersect", c("Hits", "Hits"), function(x, y) {
-  if (!compatibleHits(x, y))
-    stop("'x' and 'y' are incompatible by subject and query length")
-  x[x %in% y]
-})
-
 
 ### - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 ### setdiff()
 ###
 
-setMethod("setdiff", c("IRanges", "IRanges"),
+setMethod("setdiff", c("Ranges", "Ranges"),
     function(x, y, ...)
     {
         if (length(x) == 0L)
@@ -146,12 +123,6 @@ setMethod("setdiff", c("CompressedIRangesList", "CompressedIRangesList"),
             gaps(union(gaps(x), y), start = startx, end = endx)
           })
 
-setMethod("setdiff", c("Hits", "Hits"), function(x, y) {
-  if (!compatibleHits(x, y))
-    stop("'x' and 'y' are incompatible by subject and query length")
-  x[!(x %in% y)]
-})
-
 
 ### - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 ### punion()
@@ -161,7 +132,7 @@ setGeneric("punion", signature=c("x", "y"),
     function(x, y, ...) standardGeneric("punion")
 )
 
-setMethod("punion", c("IRanges", "IRanges"),
+setMethod("punion", c("Ranges", "Ranges"),
     function(x, y, fill.gap=FALSE, ...)
     {
         if (length(x) != length(y))
@@ -195,7 +166,7 @@ setGeneric("pintersect", signature=c("x", "y"),
     function(x, y, ...) standardGeneric("pintersect")
 )
 
-setMethod("pintersect", c("IRanges", "IRanges"),
+setMethod("pintersect", c("Ranges", "Ranges"),
     function(x, y, resolve.empty=c("none", "max.start", "start.x"), ...)
     {
         if (length(x) != length(y))
@@ -255,7 +226,7 @@ setGeneric("psetdiff", signature=c("x", "y"),
     function(x, y, ...) standardGeneric("psetdiff")
 )
 
-setMethod("psetdiff", c("IRanges", "IRanges"),
+setMethod("psetdiff", c("Ranges", "Ranges"),
     function(x, y, ...)
     {
         if (length(x) != length(y))
@@ -290,7 +261,7 @@ setGeneric("pgap", signature=c("x", "y"),
     function(x, y, ...) standardGeneric("pgap")
 )
 
-setMethod("pgap", c("IRanges", "IRanges"),
+setMethod("pgap", c("Ranges", "Ranges"),
     function(x, y, ...)
     {
         if (length(x) != length(y))
