@@ -25,8 +25,8 @@ library(IRanges)
 set.seed(0)
 lambda <- c(rep(0.001, 4500), seq(0.001, 10, length = 500), 
             seq(10, 0.001, length = 500))
-xVector <- rpois(1e7, lambda)
-yVector <- rpois(1e7, lambda[c(251:length(lambda), 1:250)])
+xVector <- Rle(rpois(1e7, lambda))
+yVector <- Rle(rpois(1e7, lambda[c(251:length(lambda), 1:250)]))
 
 
 ###################################################
@@ -40,13 +40,12 @@ zVector <- c(xVector, yVector)
 ###################################################
 ### code chunk number 6: seq-extraction
 ###################################################
-xSnippet <- window(xVector, start = 4751, end = 4760)
+xSnippet <- xVector[IRanges(4751, 4760)]
 xSnippet
 head(xSnippet)
 tail(xSnippet)
 rev(xSnippet)
 rep(xSnippet, 2)
-window(xSnippet, delta = 2)
 subset(xSnippet, xSnippet >= 5L)
 
 
@@ -313,33 +312,33 @@ shift(ir, 10)
 
 
 ###################################################
-### code chunk number 40: ranges-plus
-###################################################
-ir + seq_len(length(ir))
-
-
-###################################################
-### code chunk number 41: ranges-asterisk
-###################################################
-ir * -2 # half the width
-
-
-###################################################
-### code chunk number 42: ranges-narrow
+### code chunk number 40: ranges-narrow
 ###################################################
 narrow(ir, start=1:5, width=2)
 
 
 ###################################################
-### code chunk number 43: ranges-threebands
+### code chunk number 41: ranges-restrict
+###################################################
+restrict(ir, start=2, end=3)
+
+
+###################################################
+### code chunk number 42: ranges-threebands
 ###################################################
 threebands(ir, start=1:5, width=2)
 
 
 ###################################################
-### code chunk number 44: ranges-restrict
+### code chunk number 43: ranges-plus
 ###################################################
-restrict(ir, start=2, end=3)
+ir + seq_len(length(ir))
+
+
+###################################################
+### code chunk number 44: ranges-asterisk
+###################################################
+ir * -2 # double the width
 
 
 ###################################################
