@@ -213,22 +213,6 @@ test_CompressedIRangesList_disjoin <- function()
     checkIdentical(disjoin(r0), disjoin(irl)[[2]])
 }
 
-test_Ranges_isDisjoint <- function() {
-  ir1 <- IRanges(c(2,5,1), c(3,7,3))
-  ir2 <- IRanges(c(2,9,5), c(3,9,6))
-  ir3 <- IRanges(1, 5)
-  checkIdentical(isDisjoint(ir1), FALSE)
-  checkIdentical(isDisjoint(ir2), TRUE)
-  checkIdentical(isDisjoint(ir3), TRUE)
-
-  ## Handling of zero-width ranges
-  current <- sapply(11:17,
-                    function(i)
-                      isDisjoint(IRanges(c(12, i), width=c(4, 0))))
-  target <- rep(c(TRUE, FALSE, TRUE), c(2, 3, 2))
-  checkIdentical(target, current)
-}
-
 test_Ranges_disjointBins <- function()
 {
   checkIdentical(disjointBins(IRanges()), integer())
